#!/bin/sh
#------------------------------------------------------------------------------
# /tmp/install.sh - installation file
#
# Copyright (c) 2015-2019  The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:    2015-09-13 jed
# Last Update: $Id: install.sh 61869 2019-01-01 14:58:52Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#------------------------------------------------------------------------------

# read eislib etc.
. /var/install/include/eislib
. /var/install/include/jedlib

# package
module_name='automx'

# file names
config_file=/etc/config.d/${module_name}
package_filelist=/etc/filelist.d/${module_name}-files.txt

myecho --pack ${module_name} --info "running install.sh ..."

# update shared library file
update_jedlib ${module_name}

# menue entry does not exist - create it
myecho --pack ${module_name} "adding ${module_name} module menu ..."

# mail package found
/var/install/bin/add-menu --menu "setup.services.mail.modules.menu" \
                                 "setup.services.mail.modules.${module_name}.menu" "AutoMX administration"

# move old files to backup directory and create backup
/var/install/bin/backup-file --quiet ${module_name}

# install/update package configuration file
silent=''
if called_from_install --pack "${module_name}"
then
    silent='--quiet'

    # update mail modules menu
    /var/install/config.d/mail.sh --updatemodulesmenu > /dev/null
else
    # update mail modules menu
    /var/install/config.d/mail.sh --updatemodulesmenu
fi

update=false
if install_config ${silent} ${module_name}
then
    update=true
fi

# compile python modules
myecho --pack ${module_name} "compiling Python modules ..."

if [ -f ${package_filelist} ]
then
    for PNAME in `grep "\.py[^a-z]*$" ${package_filelist} | cut -d' ' -f6`
    do
        if [ -f /${PNAME} ]
        then
            if called_from_install --pack "${module_name}"
            then
                # be quiet
                /usr/bin/python -m compileall /${PNAME} >/dev/null
            else
                /usr/bin/python -m compileall /${PNAME}
            fi
        fi
    done
fi

# configuration
myecho --pack ${module_name} "creating ${module_name} configuration ..."

# updated installation
/var/install/config.d/${module_name}.sh

if [ -f /etc/init.d/${module_name} ]
then
    /etc/init.d/${module_name} restart
fi

exit 0
