#!/bin/sh
#------------------------------------------------------------------------------
# /tmp/preinstall.sh - pre-installation file
#
# Copyright (c) 2015-2019  The Eisfair Team, team(at)eisfair(dot)org
#
# Creation   : 2015-09-13 jed
# Last Update: $Id: preinstall.sh 61869 2019-01-01 14:58:52Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#------------------------------------------------------------------------------

module_name='automx'

# file names
config_file=/etc/config.d/${module_name}
installfile=/var/run/${module_name}.install
deinstall_file=/var/install/deinstall/${module_name}
packagefile=/var/install/packages/${module_name}

# extract shared library file from archive
# to be able to use the myecho command
archivefile=`find /tmp -maxdepth 1 -type l -name "${module_name}.tar.*" ! -name "*.info" | head -n1`

if [ -n "${archivefile}" ]
then
    if [ -s "${archivefile}" ]
    then
        tar xjf ${archivefile} var/install/include/jedlib.${module_name} -C /

        srcfile=/var/install/include/jedlib.${module_name}
        destfile=/var/install/include/jedlib

        if [ -f ${srcfile} ]
        then
            if [ -f ${destfile} ]
            then
                srcver=`/bin/sh ${srcfile} version`
                destver=`/bin/sh ${destfile} version`

                if [ -n "${destver}" ]
                then
                    # version number exists - compare version numbers
                    if [ `echo "${srcver} > ${destver}" | bc` -eq 1 ]
                    then
                        # update file
                        echo "updating shared library file (${destver}->${srcver}) ..."
                        mv -v ${srcfile} ${destfile}
                    fi
                else
                    # no version number exists - update file
                    echo "updating shared library file ..."
                    mv -v ${srcfile} ${destfile}
                fi
            else
                # file doesn't exist - update file
                echo "updating shared library file ..."
                mv -v ${srcfile} ${destfile}
            fi
        fi
    fi
fi

# read eislib etc.
. /var/install/include/eislib
. /var/install/include/jedlib

# required versions
myecho --pack ${module_name} --info "running preinstall.sh ..."

# backup existing file
if [ -f ${config_file} ]
then
    myecho --pack ${module_name} "saving previous configuration file to ${installfile} ..."
    cp ${config_file} ${installfile}
fi

# deinstall old software
myecho --pack ${module_name} "deinstalling previously installed software ..."
/usr/bin/eisman uninstall --update --auto --quiet ${module_name}

exit 0
